@@ -66,9 +66,6 @@ import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.slf4j.Logger;
-import com.openexchange.config.lean.DefaultProperty;
-import com.openexchange.config.lean.LeanConfigurationService;
-import com.openexchange.config.lean.Property;
 import com.openexchange.configuration.ServerConfig;
 import com.openexchange.http.deferrer.CustomRedirectURLDetermination;
 import com.openexchange.http.deferrer.impl.DefaultDeferringURLService;
@@ -84,21 +81,16 @@ public class DeferrerServlet extends HttpServlet {
 
     private static final long serialVersionUID = 1358634554782437089L;
 
-    private static final Property MAX_PARAMETER_LENGTH_PROP = new DefaultProperty("com.openexchange.http.deferrer.maxParameterLength", Long.valueOf(1024*10l)); // 10 KB
-
     /**
      * The listing for custom handlers.
      */
     public static final List<CustomRedirectURLDetermination> CUSTOM_HANDLERS = new CopyOnWriteArrayList<CustomRedirectURLDetermination>();
 
-    private final long maxParameterLength;
-
     /**
      * Initializes a new {@link DeferrerServlet}.
      */
-    public DeferrerServlet(LeanConfigurationService lean) {
+    public DeferrerServlet() {
         super();
-        this.maxParameterLength = null != lean ? lean.getLongProperty(MAX_PARAMETER_LENGTH_PROP) : -1;
     }
 
     @Override
@@ -141,8 +133,6 @@ public class DeferrerServlet extends HttpServlet {
 
         Map<String, String> params = parseQueryStringFromUrl(redirectURL);
         StringBuilder builder = new StringBuilder(encodeUrl(redirectURL, true, false));
-        String defaultCharEnc = maxParameterLength > 0 ? ServerConfig.getProperty(ServerConfig.Property.DefaultEncoding) : null;
-        long size = 0;
         for (Enumeration<?> parameterNames = req.getParameterNames(); parameterNames.hasMoreElements();) {
             String name = (String) parameterNames.nextElement();
             if ("redirect".equals(name) || params.containsKey(name)) {
@@ -150,15 +140,6 @@ public class DeferrerServlet extends HttpServlet {
             }
 
             String parameter = req.getParameter(name);
-            if (maxParameterLength > 0) {
-                // Add both the parameter's name size and the parameter's content size
-                size += ((name != null ? name.getBytes(defaultCharEnc).length : 0) + (parameter != null ? parameter.getBytes(defaultCharEnc).length : 0));
-                if (size >= maxParameterLength) {
-                    Tools.sendErrorPage(resp, HttpServletResponse.SC_REQUEST_URI_TOO_LONG, "Request parameters contain too much data");
-                    return;
-                }
-            }
-
             builder.append(concat);
             concat = '&';
             builder.append(name).append('=').append(encodeUrl(parameter, true, false));
