@@ -49,16 +49,25 @@
 
 package com.openexchange.oauth.dropbox.osgi;
 
+import java.util.Dictionary;
+import java.util.Hashtable;
+import com.openexchange.capabilities.CapabilityChecker;
+import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
+import com.openexchange.exception.OXException;
+import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.oauth.dropbox.DropboxOAuthScope;
 import com.openexchange.oauth.dropbox.DropboxOAuthServiceMetaData;
 import com.openexchange.oauth.scope.OAuthScopeRegistry;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.session.Session;
+import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * {@link DropboxOAuthActivator}
@@ -73,30 +82,53 @@ public final class DropboxOAuthActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, OAuthScopeRegistry.class, DispatcherPrefixService.class, SSLConfigurationService.class };
+        return new Class<?>[] { ConfigurationService.class, DeferringURLService.class, CapabilityService.class, OAuthScopeRegistry.class, DispatcherPrefixService.class, SSLConfigurationService.class };
     }
 
     @Override
     protected void startBundle() throws Exception {
         DropboxOAuthServices.setServices(this);
-        DropboxOAuthServiceMetaData service = new DropboxOAuthServiceMetaData(this);
-        registerService(OAuthServiceMetaData.class, service);
-        registerService(Reloadable.class, service);
+        final DropboxOAuthServiceMetaData service = new DropboxOAuthServiceMetaData(this);
+
         track(DatabaseService.class, new DatabaseUpdateTaskServiceTracker(context));
         openTrackers();
 
+        registerService(OAuthServiceMetaData.class, service);
+        registerService(Reloadable.class, service);
+
+        Dictionary<String, Object> properties = new Hashtable<String, Object>(1);
+        properties.put(CapabilityChecker.PROPERTY_CAPABILITIES, "dropbox");
+        registerService(CapabilityChecker.class, new CapabilityChecker() {
+
+            @Override
+            public boolean isEnabled(String capability, Session ses) throws OXException {
+                if ("dropbox".equals(capability)) {
+                    final ServerSession session = ServerSessionAdapter.valueOf(ses);
+                    if (session.isAnonymous() || session.getUser().isGuest()) {
+                        return false;
+                    }
+
+                    return service.isEnabled(session.getUserId(), session.getContextId());
+                }
+
+                return true;
+            }
+        }, properties);
+
+        getService(CapabilityService.class).declareCapability("dropbox");
+
         // Register the scope
         OAuthScopeRegistry scopeRegistry = getService(OAuthScopeRegistry.class);
         scopeRegistry.registerScope(service.getAPI(), DropboxOAuthScope.drive);
     }
 
     @Override
-    protected void stopBundle() {
+    protected void stopBundle() throws Exception {
         try {
-            // Clean-up
-            cleanUp();
             // Clear service registry
             DropboxOAuthServices.setServices(null);
+
+            super.stopBundle();
         } catch (final Exception e) {
             org.slf4j.LoggerFactory.getLogger(DropboxOAuthActivator.class).error("", e);
             throw e;
