@@ -53,6 +53,7 @@ import java.util.Collection;
 import java.util.Collections;
 import org.scribe.builder.api.Api;
 import org.scribe.builder.api.MsLiveConnectApi;
+import org.scribe.model.Verb;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.impl.AbstractExtendedScribeAwareOAuthServiceMetaData;
 import com.openexchange.server.ServiceLookup;
@@ -65,6 +66,9 @@ import com.openexchange.server.ServiceLookup;
  */
 public final class MsLiveConnectOAuthServiceMetaData extends AbstractExtendedScribeAwareOAuthServiceMetaData {
 
+    private static final String IDENTITY_URL = "https://apis.live.net/v5.0/me";
+    private static final String IDENTITY_FIELD_NAME = "id";
+
     /**
      * Initialises a new {@link MsLiveConnectOAuthServiceMetaData}.
      *
@@ -88,4 +92,45 @@ public final class MsLiveConnectOAuthServiceMetaData extends AbstractExtendedScr
     public Class<? extends Api> getScribeService() {
         return MsLiveConnectApi.class;
     }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityMethod()
+     */
+    @Override
+    public Verb getIdentityHTTPMethod() {
+        return Verb.GET;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityURL()
+     */
+    @Override
+    public String getIdentityURL(String accessToken) {
+        return IDENTITY_URL;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityPattern()
+     */
+    @Override
+    public String getIdentityFieldName() {
+        return IDENTITY_FIELD_NAME;
+    }
+
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.openexchange.oauth.impl.AbstractScribeAwareOAuthServiceMetaData#getContentType()
+     */
+    @Override
+    public String getContentType() {
+        // No 'Content-Type' is expected for the GET /me call
+        return EMPTY_CONTENT_TYPE;
+    }
 }
