@@ -126,16 +126,16 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
             @Override
             public XingOAuthAccess accessFor(final int oauthAccountId, final Session session) throws OXException {
                 final OAuthService oAuthService = getService(OAuthService.class);
-                final OAuthAccount oAuthAccount = oAuthService.getAccount(oauthAccountId, session, session.getUserId(), session.getContextId());
+                final OAuthAccount oAuthAccount = oAuthService.getAccount(session, oauthAccountId);
 
                 OAuthAccessRegistryService registryService = Services.getService(OAuthAccessRegistryService.class);
                 OAuthAccessRegistry registry = registryService.get(KnownApi.XING.getFullName());
-                OAuthAccess oAuthAccess = registry.get(session.getContextId(), session.getUserId());
+                OAuthAccess oAuthAccess = registry.get(session.getContextId(), session.getUserId(), oAuthAccount.getId());
                 if (oAuthAccess == null) {
                     // Create
                     XingOAuthAccessImpl newInstance = new XingOAuthAccessImpl(session, oAuthAccount);
                     // Add to registry & return
-                    oAuthAccess = registry.addIfAbsent(session.getContextId(), session.getUserId(), newInstance, new InitializeCallable(newInstance));
+                    oAuthAccess = registry.addIfAbsent(session.getContextId(), session.getUserId(), oAuthAccount.getId(), newInstance, new InitializeCallable(newInstance));
                     if (null == oAuthAccess) {
                         oAuthAccess = newInstance;
                     }
