@@ -49,6 +49,8 @@
 
 package com.openexchange.xing.osgi;
 
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
@@ -71,7 +73,7 @@ public final class XingActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { TimerService.class, ThreadPoolService.class };
+        return new Class<?>[] { TimerService.class, ThreadPoolService.class, SSLSocketFactoryProvider.class, SSLConfigurationService.class };
     }
 
     @Override
